==> ideaIC-15.0.3-sources.jar: com/intellij/openapi/editor/actions/UnselectPreviousOccurrenceAction.java <==
/*
 * Copyright 2000-2014 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.openapi.editor.actions;

import com.intellij.openapi.actionSystem.DataContext;
import com.intellij.openapi.editor.Caret;
import com.intellij.openapi.editor.Editor;
import com.intellij.openapi.editor.ScrollType;
import com.intellij.openapi.editor.actionSystem.EditorAction;
import org.jetbrains.annotations.Nullable;

public class UnselectPreviousOccurrenceAction extends EditorAction {
  protected UnselectPreviousOccurrenceAction() {
    super(new Handler());
  }

  private static class Handler extends SelectOccurrencesActionHandler {
    @Override
    public boolean isEnabled(Editor editor, DataContext dataContext) {
      return super.isEnabled(editor, dataContext) && editor.getCaretModel().supportsMultipleCarets();
    }

    @Override
    public void doExecute(Editor editor, @Nullable Caret caret, DataContext dataContext) {
      if (editor.getCaretModel().getCaretCount() > 1) {
        editor.getCaretModel().removeCaret(editor.getCaretModel().getPrimaryCaret());
      }
      else {
        editor.getSelectionModel().removeSelection();
      }
      getAndResetNotFoundStatus(editor);
      editor.getScrollingModel().scrollToCaret(ScrollType.RELATIVE);
    }
  }
}

==> ideaIC-171.2014.21-sources.jar: com/intellij/openapi/editor/actions/UnselectPreviousOccurrenceAction.java <==
/*
 * Copyright 2000-2014 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.openapi.editor.actions;

import com.intellij.openapi.actionSystem.DataContext;
import com.intellij.openapi.editor.Caret;
import com.intellij.openapi.editor.Editor;
import com.intellij.openapi.editor.ScrollType;
import com.intellij.openapi.editor.actionSystem.EditorAction;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class UnselectPreviousOccurrenceAction extends EditorAction {
  protected UnselectPreviousOccurrenceAction() {
    super(new Handler());
  }

  private static class Handler extends SelectOccurrencesActionHandler {
    @Override
    public boolean isEnabledForCaret(@NotNull Editor editor, @NotNull Caret caret, DataContext dataContext) {
      return editor.getCaretModel().supportsMultipleCarets();
    }

    @Override
    public void doExecute(Editor editor, @Nullable Caret caret, DataContext dataContext) {
      if (editor.getCaretModel().getCaretCount() > 1) {
        editor.getCaretModel().removeCaret(editor.getCaretModel().getPrimaryCaret());
      }
      else {
        editor.getSelectionModel().removeSelection();
      }
      getAndResetNotFoundStatus(editor);
      editor.getScrollingModel().scrollToCaret(ScrollType.RELATIVE);
    }
  }
}
